# scons_msvc_env

[![License - MIT](https://img.shields.io/badge/license-MIT-green)](https://spdx.org/licenses/MIT.html)

-----

scons_msvc_env is my way of using the [Microsoft Visual C++](
https://visualstudio.microsoft.com/vs/features/cplusplus/) compiler in
conjunction with [SCons](https://scons.org/).

